@@ -218,8 +218,6 @@ get_note_icon (BijibenShellSearchProviderApp *self,
       gicon = G_ICON (gdk_pixbuf_get_from_surface (surface, 0, 0,
                                                    cairo_image_surface_get_width (surface),
                                                    cairo_image_surface_get_height (surface)));
-
-      cairo_surface_destroy (surface);
     }
 
   if (gicon == NULL)
@@ -423,6 +421,7 @@ bijiben_shell_search_provider_app_init (BijibenShellSearchProviderApp *self)
   char *storage_path;
   GFile *storage;
   GdkRGBA color = { 0, 0, 0, 0 };
+#ifdef TRACKER_PRIVATE_STORE
   g_autofree char *filename = NULL;
   g_autoptr (GFile) data_location = NULL;
 
@@ -436,6 +435,9 @@ bijiben_shell_search_provider_app_init (BijibenShellSearchProviderApp *self)
                                                           data_location,
                                                           NULL, NULL, NULL,
                                                           &error);
+#else
+  self->connection = tracker_sparql_connection_get (NULL, &error);
+#endif
 
   if (error)
   {
