@@ -390,12 +390,21 @@ bijiben_startup (GApplication *application)
   g_autoptr(GError) error = NULL;
   GdkRGBA         color = {0,0,0,0};
 
+  const gchar *vaccels_detach[] = {"<Primary>d", NULL};
+  const gchar *vaccels_redo[] = {"<Primary><Shift>z", NULL};
+  const gchar *vaccels_undo[] = {"<Primary>z", NULL};
+  const gchar *vaccels_trash[] = {"<Primary>Delete", NULL};
 
   G_APPLICATION_CLASS (bjb_application_parent_class)->startup (application);
   self = BJB_APPLICATION (application);
 
   bjb_apply_style ();
 
+  gtk_application_set_accels_for_action (GTK_APPLICATION (application), "win.detach-window", vaccels_detach);	
+  gtk_application_set_accels_for_action (GTK_APPLICATION (application), "win.redo", vaccels_redo);
+  gtk_application_set_accels_for_action (GTK_APPLICATION (application), "win.undo", vaccels_undo);
+  gtk_application_set_accels_for_action (GTK_APPLICATION (application), "win.trash", vaccels_trash);
+
   g_action_map_add_action_entries (G_ACTION_MAP (application),
                                    app_entries,
                                    G_N_ELEMENTS (app_entries),
