@@ -314,9 +314,13 @@ on_back_button_clicked (BjbMainToolbar *self)
 
   if (self->note)
     {
+      if (biji_note_obj_is_trashed (self->note))
+        bjb_window_base_switch_to (BJB_WINDOW_BASE (self->window),
+                                   BJB_WINDOW_BASE_ARCHIVE_VIEW);
+      else
+        bjb_window_base_switch_to (BJB_WINDOW_BASE (self->window),
+                                   BJB_WINDOW_BASE_MAIN_VIEW);
       disconnect_note_handlers (self);
-      bjb_window_base_switch_to (BJB_WINDOW_BASE (self->window),
-                                 BJB_WINDOW_BASE_MAIN_VIEW);
       bjb_main_view_update_model (self->parent);
       return;
     }
@@ -499,6 +503,11 @@ populate_bar_for_note_view (BjbMainToolbar *self)
                                G_CALLBACK (on_note_color_changed), self->color_button);
   }
 
+  if (biji_note_obj_is_trashed (self->note))
+    gtk_widget_hide (self->trash_item);
+  else
+    gtk_widget_show (self->trash_item);
+
   /* Note Last Updated */
   on_last_updated_cb (BIJI_ITEM (self->note), self);
   self->last_updated = g_signal_connect (self->note,"changed",
