@@ -155,7 +155,9 @@ action_share_item_callback (BjbSelectionToolbar *self,
   selection = bjb_main_view_get_selected_items (self->view);
 
   for (l = selection; l != NULL; l = l->next)
-    on_email_note_callback (GTK_WIDGET (button), l->data);
+    {
+      on_email_note_callback (l->data);
+    }
 
   bjb_main_view_set_selection_mode (self->view, FALSE);
   g_list_free (selection);
@@ -399,7 +401,7 @@ bjb_selection_toolbar_class_init (BjbSelectionToolbarClass *class)
 
   g_object_class_install_property (object_class,PROP_BJB_MAIN_VIEW,properties[PROP_BJB_MAIN_VIEW]);
 
-  gtk_widget_class_set_template_from_resource (widget_class, "/org/gnome/bijiben/ui/selection-toolbar.ui");
+  gtk_widget_class_set_template_from_resource (widget_class, "/org/gnome/Notes/ui/selection-toolbar.ui");
 
   gtk_widget_class_bind_template_child (widget_class, BjbSelectionToolbar, button_stack);
   gtk_widget_class_bind_template_child (widget_class, BjbSelectionToolbar, notebook_button);
