@@ -46,7 +46,7 @@ biji_error_quark (void)
 
 GError *
 biji_error_new (BijiErrorType type,
-                gchar *message)
+                const gchar *message)
 {
   return g_error_new_literal (BIJI_ERROR, type, message);
 }
